@@ -14,13 +14,14 @@
  * limitations under the License.
  */
 
-//! TLS protocol related components for DNS over TLS
+//! Deprecated and moved to trust_dns_proto::native_tls
 
 // LIBRARY WARNINGS
 #![warn(
     clippy::dbg_macro,
     clippy::print_stdout,
     clippy::unimplemented,
+    clippy::use_self,
     missing_copy_implementations,
     missing_docs,
     non_snake_case,
@@ -28,13 +29,6 @@
     rust_2018_idioms,
     unreachable_pub
 )]
-#![allow(clippy::single_component_path_imports)]
+#![deprecated = "moved to trust_dns_proto::native_tls"]
 
-pub mod tls_client_stream;
-pub mod tls_stream;
-
-pub use self::tls_client_stream::{TlsClientStream, TlsClientStreamBuilder};
-pub use self::tls_stream::{TlsStream, TlsStreamBuilder};
-
-#[cfg(test)]
-mod tests;
+pub use trust_dns_proto::native_tls::*;
